@@ -92,7 +92,7 @@ mod fixtures {
 
     pub use pueue_lib::network::message::*;
     pub use pueue_lib::network::protocol::socket_cleanup;
-    pub use pueue_lib::settings::Settings;
+    pub use pueue_lib::settings::{Settings, PUEUE_DEFAULT_GROUP};
     pub use pueue_lib::state::{SharedState, State};
     pub use pueue_lib::task::{Task, TaskResult, TaskStatus};
 
@@ -133,7 +133,7 @@ mod fixtures {
             format!("{}", id),
             "/tmp".to_string(),
             HashMap::new(),
-            "default".to_string(),
+            PUEUE_DEFAULT_GROUP.to_string(),
             status,
             Vec::new(),
             None,
